@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Lister;
-$Config::Model::Lister::VERSION = '2.133';
+package Config::Model::Lister 2.136;
+
 use strict;
 use warnings;
 use Exporter;
@@ -44,8 +44,8 @@ sub available_models {
 
             $appli_info{$appli}{_file} = $file;
             $appli_info{$appli}{_category} = $cat;
-            open( F, $file ) || die "Can't open file $file:$!";
-            while (<F>) {
+            open my $fh, '<', $file || die "Can't open file $file:$!";
+            while (<$fh>) {
                 chomp;
                 s/^\s+//;
                 s/\s+$//;
@@ -92,7 +92,7 @@ Config::Model::Lister - List available models and applications
 
 =head1 VERSION
 
-version 2.133
+version 2.136
 
 =head1 SYNOPSIS
 
@@ -151,7 +151,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
