@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Role::HelpAsText;
-$Config::Model::Role::HelpAsText::VERSION = '2.133';
+package Config::Model::Role::HelpAsText 2.136;
+
 # ABSTRACT: Translate element help from pod to text
 
 use Mouse::Role;
@@ -24,7 +24,7 @@ sub get_help_as_text {
     my $self = shift;
 
     my $pod = $self->get_help(@_) ;
-    return undef unless defined $pod;
+    return unless defined $pod;
 
     my $parser = Pod::Text->new(
         indent => 0,
@@ -57,7 +57,7 @@ Config::Model::Role::HelpAsText - Translate element help from pod to text
 
 =head1 VERSION
 
-version 2.133
+version 2.136
 
 =head1 SYNOPSIS
 
@@ -88,7 +88,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
