@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model
 #
-# This software is Copyright (c) 2005-2018 by Dominique Dumont.
+# This software is Copyright (c) 2005-2019 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
-package Config::Model::Value;
-$Config::Model::Value::VERSION = '2.133';
+package Config::Model::Value 2.136;
+
 use 5.10.1;
 
 use strict;
@@ -931,7 +931,11 @@ sub check_value {
         my $prd_check = $prd->check( $value, 1, $self, \$err_msg, \$warn_msg );
         my $prd_result = defined $prd_check ? 1 : 0;
         $logger->debug( "grammar check on $value returned ", defined $prd_check ? $prd_check : '<undef>' );
-        push @error, $err_msg || "value '$value' does not match grammar from model" unless $prd_result;
+        if (not $prd_result) {
+            my $msg = "value '$value' does not match grammar from model";
+            $msg .= ": $err_msg" if $err_msg;
+            push @error, $msg;
+        }
         push @warn, $warn_msg if $warn_msg;
     }
 
@@ -1488,7 +1492,7 @@ sub load_data {
 
     my $rd = ref $data;
 
-    if ( $rd and grep { $rd eq $_ } qw/ARRAY HASH SCALAR/) {
+    if ( $rd and any { $rd eq $_ } qw/ARRAY HASH SCALAR/) {
         Config::Model::Exception::LoadData->throw(
             object     => $self,
             message    => "load_data called with non scalar arg",
@@ -1915,7 +1919,7 @@ Config::Model::Value - Strongly typed configuration value
 
 =head1 VERSION
 
-version 2.133
+version 2.136
 
 =head1 SYNOPSIS
 
@@ -2985,7 +2989,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2005-2018 by Dominique Dumont.
+This software is Copyright (c) 2005-2019 by Dominique Dumont.
 
 This is free software, licensed under:
 
